==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/settings/l10n/oc.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Local" : "Local",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
    "Verify" : "Verificar",
    "Verifying …" : "Verificacion…",
    "Unable to change password" : "Cambiament impossible del senhal",
    "Very weak password" : "Senhal plan feble",
    "Weak password" : "Senhal feble",
    "So-so password" : "Senhal mejan",
    "Good password" : "Bon senhal",
    "Strong password" : "Senhal fòrt",
    "Groups" : "Gropes",
    "Group list is empty" : "La lista de grop es voida",
    "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
    "{actor} added you to group {group}" : "{actor} vos a apondut al grop {group}",
    "You added {user} to group {group}" : "Avètz apondut {user} al grop {group}",
    "{actor} added {user} to group {group}" : "{actor} apondèt {user} al grop {group}",
    "An administrator added you to group {group}" : "Un administrator vos apondèt al grop {group}",
    "An administrator added {user} to group {group}" : "Un administrator apondèt {user} al grop {group}",
    "{actor} removed you from group {group}" : "{actor} vos levèt d’al grop {group}",
    "You removed {user} from group {group}" : "Levèretz {user} d’al grop {group}",
    "{actor} removed {user} from group {group}" : "{actor} levèt {user} d’al grop {group}",
    "An administrator removed you from group {group}" : "Un administrator vos levèt d’al grop {group}",
    "An administrator removed {user} from group {group}" : "Un administrator levèt {user} d’al grop {group}",
    "{actor} changed your password" : "{actor} a cambiat vòstre senhal",
    "You changed your password" : "Avètz cambiat de senhal",
    "Your password was reset by an administrator" : "Un administrator a reïnicializat vòstre senhal",
    "Your password was reset" : "Qualqu’un a reïnicializat vòstre senhal",
    "{actor} changed your email address" : "{actor} cambièt vòstra adreça email",
    "You changed your email address" : "Avètz cambiat vòstra adreça email",
    "Your email address was changed by an administrator" : "Un administrator cambièt vòstra adreça email",
    "You created app password \"{token}\"" : "Avètz creat lo senhal d’aplicacion « {token} »",
    "You deleted app password \"{token}\"" : "Avètz suprimit lo senhal d’aplicacion « {token} »",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Avètz renommat lo senhal d’aplicacion « {token} » en « {newToken} »",
    "Security" : "Seguretat",
    "Wrong password" : "Wrong password",
    "Saved" : "Enregistrat",
    "Authentication error" : "Error d’autentificacion",
    "Invalid SMTP password." : "Senhal SMTP invalid.",
    "Email setting test" : "Paramètres email de pròva",
    "Well done, %s!" : "Felicitacion, %s !",
    "Invalid user" : "Utilizaire invalid",
    "Invalid mail address" : "Adreça email invalida",
    "Settings saved" : "Paramètres enregistrats",
    "Welcome aboard" : "La benvenguda a bòrd",
    "Welcome aboard %s" : "La benvenguda a bòrd %s",
    "Your username is: %s" : "Vòstre nom d’utilizaire : %s",
    "Set your password" : "Definir vòstre senhal",
    "Go to %s" : "Anar a %s",
    "Install Client" : "Installar client",
    "Apps" : "Aplicacions",
    "Settings" : "Paramètres",
    "Personal" : "Personal",
    "Administration" : "Administracion",
    "Additional settings" : "Paramètres addicionals",
    "Administration privileges" : "Privilègis d’administracion",
    "Overview" : "Apercebut",
    "Basic settings" : "Paramètres de basa",
    "Sharing" : "Partiment",
    "Availability" : "Disponibilitat",
    "Personal info" : "Info personalas",
    "Mobile & desktop" : "Mobile e burèu",
    "Email server" : "Servidor email",
    "Background jobs" : "Prètzfaches de rèireplan",
    "Create" : "Crear",
    "Change" : "Modificar",
    "Delete" : "Suprimir",
    "Reshare" : "Repartir",
    "Unlimited" : "Illimitat",
    "Verifying" : "Verificacion",
    "Nextcloud settings" : "Paramètres Nextcloud",
    "None" : "Pas cap",
    "Two-Factor Authentication" : "Autentificacion dos factors",
    "Limit to groups" : "Limitar als grops",
    "Save changes" : "Enregistrar las modificacions",
    "All" : "Tot",
    "No results" : "Cap de resultat",
    "Update to {version}" : "Metre a jorn cap a {version}",
    "Remove" : "Suprimir",
    "Disable" : "Desactivar",
    "View in store" : "Veire a la botiga",
    "Visit website" : "Veire lo site web",
    "Report a bug" : "Raportar un bug",
    "User documentation" : "Documentacion utilizaire",
    "Admin documentation" : "Documentacion d’admin",
    "Developer documentation" : "Documentacion desvolopaire",
    "Update to {update}" : "Actualizar en {update}",
    "Disable all" : "Desactivar tot",
    "Enable all" : "Activar tot",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicacion an una mesa a jorn de disponibla","%n aplicacions an una mesa a jorn de disponibla"],
    "Device settings" : "Paramètres periferic",
    "Allow filesystem access" : "Permetre accès filesystem",
    "Rename" : "Renomenar",
    "Revoke" : "Revocar",
    "Wipe device" : "Tirar periferic",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome per Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "Aplicacion iOS {productName}",
    "{productName} Android app" : "Aplicacion Android {productName}",
    "{productName} Talk for iOS" : "Talk de {productName} per iOS",
    "{productName} Talk for Android" : "Talk de {productName} per Android",
    "This session" : "Aquesta session",
    "Device" : "Periferic",
    "Last activity" : "Darrièra activitat",
    "Devices & sessions" : "Periferics e sessions",
    "App name" : "Nom d’aplicacion",
    "Username" : "Nom d'utilizaire",
    "Password" : "Senhal",
    "Done" : "Done",
    "Copied!" : "Copiat !",
    "Copy" : "Copiar",
    "Profile" : "Perfil",
    "Enable" : "Activar",
    "Remove group" : "Suprimir grop",
    "Current password" : "Senhal actual",
    "New password" : "Senhal novèl",
    "Change password" : "Cambiar de senhal",
    "png or jpg, max. 20 MB" : "png or jpg, max. 20 Mo",
    "Picture provided by original account" : "Imatge provesit pel compte d’origina",
    "Cancel" : "Anullar",
    "Your biography" : "Vòstra biografia",
    "Details" : "Detalhs",
    "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
    "Your full name" : "Vòstre nom complèt",
    "Email options" : "Opcions d’email",
    "This address is not confirmed" : "Aquesta adreça es pas confirmada",
    "Set as primary email" : "Definir coma adreça principala",
    "Your email address" : "Vòstra adreça electronica",
    "No email address set" : "Cap d’adreça pas definida",
    "Additional emails" : "Emails suplementaris",
    "Your headline" : "Vòstre títol",
    "Language" : "Lenga",
    "Help translate" : "Ajudar a traduire",
    "Unable to update language" : "Actualizacion de la lenga impossibla",
    "No language set" : "Cap de lenga pas definida",
    "Locale" : "Varianta lingüistica",
    "Your organisation" : "Vòstra organizacion",
    "Your phone number" : "Vòstre numèro de telefòn",
    "Edit your Profile visibility" : "Modificatz la visibilitat de vòstre perfil",
    "Enable Profile" : "Activar Perfil",
    "{displayId}" : "{displayId}",
    "Your role" : "Vòstre ròtle",
    "Add" : "Ajustar",
    "Add new password" : "Apondre senhal novèl",
    "Add new email address" : "Apondre adreça electronica",
    "Add user to group" : "Apondre utilizaire al grop",
    "Set user as admin for" : "Definir l’utilizaire coma admin per",
    "Select user quota" : "Seleccionar lo quota utilizaire",
    "Delete user" : "Suprimir l’utilizaire",
    "Wipe all devices" : "Escafar totes los periferics",
    "Disable user" : "Desactivar l’utilizaire",
    "Enable user" : "Activar l’utilizaire",
    "Resend welcome email" : "Tornar enviar l’email de benvenguda",
    "Account deletion" : "Supression de compte",
    "Delete {userid}'s account" : "Suprimir lo compte de {userid}",
    "Welcome mail sent!" : "Email de benvenguda enviat !",
    "Edit User" : "Modificar l’utilizaire",
    "{size} used" : "{size} utilizat",
    "New user" : "Utilizaire novèl",
    "Display name" : "Nom afichat",
    "Email" : "Adreça corrièl",
    "Default language" : "Lenga per defaut",
    "Add a new user" : "Apondre un utilizaire novè",
    "Quota" : "Quota",
    "Last login" : "Darrièra connexion",
    "No users in here" : "Cap d’utilizaire aquí",
    "Default quota" : "Quota per defaut",
    "Common languages" : "Lengas comunas",
    "Other languages" : "Autras lengas",
    "Name your device" : "Nommatz vòstre periferic",
    "Adding your device …" : "Apondon del periferic…",
    "Unnamed device" : "Periferic sens nom",
    "Passwordless Authentication" : "Autentificacion sens senhal",
    "No devices configured." : "Cap de periferic pas configurat.",
    "Your browser does not support WebAuthn." : "Vòstre navigador es pas compatible amb WebAuthn.",
    "Your apps" : "Vòstras aplicacions",
    "Active apps" : "Aplicacions activas",
    "Disabled apps" : "Aplicacions desactivadas",
    "Updates" : "Mesas a jorn",
    "Changelog" : "Nòta de version",
    "by {author}\n{license}" : "per {author}\n{license}",
    "Enter group name" : "Picatz un nom de grop",
    "Add group" : "Apondre grop",
    "Active users" : "Utilizaires actius",
    "Admins" : "Admins",
    "Disabled users" : "Utilizaires desactivats",
    "Show Languages" : "Veire las lengas",
    "Show last login" : "Afichar la darrièra connexion",
    "Not saved" : "Pas enregistrat",
    "Sending…" : "Mandadís…",
    "Email sent" : "Corrièl mandat",
    "Location" : "Emplaçament",
    "Profile picture" : "Imatge de perfil",
    "About" : "A prepaus",
    "Full name" : "Nom complèt",
    "Additional email" : "Email suplementari",
    "Headline" : "Títol",
    "Organisation" : "Organizacion",
    "Phone number" : "Numèro de telefòn",
    "Role" : "Ròtle",
    "Twitter" : "Twitter",
    "Website" : "Site web",
    "Profile visibility" : "Visibilitat perfil",
    "Show to everyone" : "Afichar a tot lo monde",
    "Hide" : "Amagar",
    "Never" : "Pas jamais",
    "Documentation" : "Documentacion",
    "Forum" : "Forum",
    "Login" : "Login",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Dobrir la documentacion",
    "Send mode" : "Mòde de mandadís",
    "Encryption" : "Chiframent",
    "Authentication required" : "Autentificacion requerida",
    "Server address" : "Adreça del servidor",
    "Port" : "Pòrt",
    "Credentials" : "Informacions d'identificacion",
    "SMTP Username" : "Utilizaire SMTP",
    "SMTP Password" : "Senhal SMTP",
    "Save" : "Salvar",
    "Send email" : "Enviar email",
    "Version" : "Version",
    "day(s)" : "jorn(s)",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desvolopat per la {communityopen}comunautat Nextcloud{linkclose}, lo {githubopen}còdi font{linkclose} es jos licéncia {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Aimar nòstra pagina Facebook",
    "Follow us on Twitter" : "Nos seguir sus Twitter",
    "Follow us on Mastodon" : "Nos seguir sus Mastodon",
    "Check out our blog" : "Donar un còp d’uèlh a nòstre blòg",
    "Subscribe to our newsletter" : "S’abonar a l’infoletra",
    "Migration in progress. Please wait until the migration is finished" : "Migracion en cors. Mercés d’esperar fins que la migracion aja acabat",
    "Migration started …" : "Migracion començada…",
    "An error occurred while changing your language. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de lenga. Mercés de recargar la pagina e tornar ensajar.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de varianta lingüistica. Mercés de recargar la pagina e tornar ensajar.",
    "Select a profile picture" : "Seleccionar un imatge de perfil",
    "Week starts on {fdow}" : "La setmana comença lo {fdow}",
    "Couldn't remove app." : "Supression impossibla de l’aplicacion.",
    "Couldn't update app." : "Mesa a jorn impossibla de l’aplicacion.",
    "All languages" : "Totas las lengas",
    "Everyone" : "Tot lo monde",
    "Test email settings" : "Ensajar los paramètres email",
    "Enable encryption" : "Activar lo chiframent",
    "Start migration" : "Començar la migracion",
    "days" : "jorns",
    "Upload new" : "Ne mandar un novèl",
    "Select from Files" : "Seleccionar dels fichièrs",
    "Remove image" : "Suprimir imatge",
    "Choose as profile picture" : "Causir coma imatge de perfil",
    "You are using <strong>%s</strong>" : "Utilizatz <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizatz <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "No display name set" : "Cap de nom d’afichatge pas definit",
    "Address" : "Adreça",
    "Your postal address" : "Vòstra adreça postala",
    "Link https://…" : "Ligam https://…",
    "Twitter handle @…" : "Escais Twitter @…",
    "Admin privileges" : "Privilègis admin",
    "Unable to update full name" : "Actualizacion impossibla del nom complet",
    "Avatar" : "Avatar"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-28.0.6.tar.bz2: nextcloud/apps/settings/l10n/oc.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Local" : "Local",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
    "Verify" : "Verificar",
    "Verifying …" : "Verificacion…",
    "Unable to change password" : "Cambiament impossible del senhal",
    "Very weak password" : "Senhal plan feble",
    "Weak password" : "Senhal feble",
    "So-so password" : "Senhal mejan",
    "Good password" : "Bon senhal",
    "Strong password" : "Senhal fòrt",
    "Groups" : "Gropes",
    "Group list is empty" : "La lista de grop es voida",
    "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
    "{actor} added you to group {group}" : "{actor} vos a apondut al grop {group}",
    "You added {user} to group {group}" : "Avètz apondut {user} al grop {group}",
    "{actor} added {user} to group {group}" : "{actor} apondèt {user} al grop {group}",
    "An administrator added you to group {group}" : "Un administrator vos apondèt al grop {group}",
    "An administrator added {user} to group {group}" : "Un administrator apondèt {user} al grop {group}",
    "{actor} removed you from group {group}" : "{actor} vos levèt d’al grop {group}",
    "You removed {user} from group {group}" : "Levèretz {user} d’al grop {group}",
    "{actor} removed {user} from group {group}" : "{actor} levèt {user} d’al grop {group}",
    "An administrator removed you from group {group}" : "Un administrator vos levèt d’al grop {group}",
    "An administrator removed {user} from group {group}" : "Un administrator levèt {user} d’al grop {group}",
    "{actor} changed your password" : "{actor} a cambiat vòstre senhal",
    "You changed your password" : "Avètz cambiat de senhal",
    "Your password was reset by an administrator" : "Un administrator a reïnicializat vòstre senhal",
    "Your password was reset" : "Qualqu’un a reïnicializat vòstre senhal",
    "{actor} changed your email address" : "{actor} cambièt vòstra adreça email",
    "You changed your email address" : "Avètz cambiat vòstra adreça email",
    "Your email address was changed by an administrator" : "Un administrator cambièt vòstra adreça email",
    "You deleted app password \"{token}\"" : "Avètz suprimit lo senhal d’aplicacion « {token} »",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Avètz renommat lo senhal d’aplicacion « {token} » en « {newToken} »",
    "Security" : "Seguretat",
    "You successfully logged in using two-factor authentication (%1$s)" : "Vos sètz corrèctament connectat via l’autentificacion a dos factors (%1$s)",
    "Settings" : "Paramètres",
    "Wrong password" : "Wrong password",
    "Saved" : "Enregistrat",
    "Authentication error" : "Error d’autentificacion",
    "User documentation" : "Documentacion utilizaire",
    "Invalid SMTP password." : "Senhal SMTP invalid.",
    "Email setting test" : "Paramètres email de pròva",
    "Well done, %s!" : "Felicitacion, %s !",
    "Invalid mail address" : "Adreça email invalida",
    "Settings saved" : "Paramètres enregistrats",
    "Welcome aboard" : "La benvenguda a bòrd",
    "Welcome aboard %s" : "La benvenguda a bòrd %s",
    "Set your password" : "Definir vòstre senhal",
    "Go to %s" : "Anar a %s",
    "Install Client" : "Installar client",
    "Apps" : "Aplicacions",
    "Personal" : "Personal",
    "Administration" : "Administracion",
    "Users" : "Utilizaires",
    "Additional settings" : "Paramètres addicionals",
    "Administration privileges" : "Privilègis d’administracion",
    "Overview" : "Apercebut",
    "Basic settings" : "Paramètres de basa",
    "Sharing" : "Partiment",
    "Availability" : "Disponibilitat",
    "Calendar" : "Calendièr",
    "Personal info" : "Info personalas",
    "Mobile & desktop" : "Mobile e burèu",
    "Email server" : "Servidor email",
    "Background jobs" : "Prètzfaches de rèireplan",
    "Unlimited" : "Illimitat",
    "Verifying" : "Verificacion",
    "Disabled" : "Desactivat",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La foncion « set_time_limit\" » es pas disponibla. Aquò poiriá menar a una execucion copada al mièg camin, e a una copadura de l’installacion. L’activacion d’aquesta foncion es forçadament recomandada.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vòstre PHP prend pas en carga FreeType, çò que causa lo rompement dels imatges de perfil e de l’interfàcia de paramètres.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sembla corrèctament configurat per interpretar las variablas d’environament del sistèma. La pròva amb getenv(\"PATH\") a pas tornar una responda voida.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuracion lectura-sola es estada activada. Aquò empacha de configurar d’unes paramètres via l’interfàcia web. Pasmens, òm deu far venir lo fichièr modificable manualament per cada mesa a jorn.",
    "Architecture" : "Arquitectura",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vòstra basa de donada s’executa pas amb la transaccion de nivèl d’isolacion « READ COMMITTED ». Aquò pòt causar problèmas quand mantuna accion s’executan en parallèl.",
    "Nextcloud settings" : "Paramètres Nextcloud",
    "None" : "Pas cap",
    "Set default expiration date for shares" : "Definir una data d’expiracion per defaut pels partatges",
    "Two-Factor Authentication" : "Autentificacion dos factors",
    "Limit to groups" : "Limitar als grops",
    "Save changes" : "Enregistrar las modificacions",
    "Update to {update}" : "Actualizar en {update}",
    "Remove" : "Suprimir",
    "Disable" : "Desactivar",
    "Name" : "Nom",
    "Version" : "Version",
    "Actions" : "Accions",
    "Disable all" : "Desactivar tot",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicacion an una mesa a jorn de disponibla","%n aplicacions an una mesa a jorn de disponibla"],
    "Loading" : "Cargament",
    "Description" : "Descripcion",
    "Details" : "Detalhs",
    "All" : "Tot",
    "No results" : "Cap de resultat",
    "Update to {version}" : "Metre a jorn cap a {version}",
    "Categories" : "Categorias",
    "Documentation" : "Documentacion",
    "Report a bug" : "Raportar un bug",
    "Request feature" : "Demanda de foncionalitat",
    "Ask questions or discuss" : "Pausar de question o discutir",
    "View in store" : "Veire a la botiga",
    "Visit website" : "Veire lo site web",
    "Admin documentation" : "Documentacion d’admin",
    "Developer documentation" : "Documentacion desvolopaire",
    "Changelog" : "Nòta de version",
    "Device settings" : "Paramètres periferic",
    "Allow filesystem access" : "Permetre accès filesystem",
    "Rename" : "Renomenar",
    "Revoke" : "Revocar",
    "Wipe device" : "Tirar periferic",
    "Google Chrome for Android" : "Google Chrome per Android",
    "{productName} iOS app" : "Aplicacion iOS {productName}",
    "{productName} Android app" : "Aplicacion Android {productName}",
    "{productName} Talk for iOS" : "Talk de {productName} per iOS",
    "{productName} Talk for Android" : "Talk de {productName} per Android",
    "This session" : "Aquesta session",
    "Device" : "Periferic",
    "Last activity" : "Darrièra activitat",
    "Devices & sessions" : "Periferics e sessions",
    "App name" : "Nom d’aplicacion",
    "Login" : "Login",
    "Password" : "Senhal",
    "Profile" : "Perfil",
    "Enable" : "Activar",
    "Cancel" : "Anullar",
    "Confirm" : "Confirmar",
    "Submit" : "Transmetre",
    "Rename group" : "Renomenar lo grop",
    "Remove group" : "Suprimir lo grop",
    "Current password" : "Senhal actual",
    "New password" : "Senhal novèl",
    "Change password" : "Cambiar de senhal",
    "Picture provided by original account" : "Imatge provesit pel compte d’origina",
    "Your biography" : "Vòstra biografia",
    "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
    "Your full name" : "Vòstre nom complèt",
    "Email options" : "Opcions d’email",
    "This address is not confirmed" : "Aquesta adreça es pas confirmada",
    "Set as primary email" : "Definir coma adreça principala",
    "No email address set" : "Cap d’adreça pas definida",
    "Your headline" : "Vòstre títol",
    "Help translate" : "Ajudar a traduire",
    "Unable to update language" : "Actualizacion de la lenga impossibla",
    "No language set" : "Cap de lenga pas definida",
    "Your organisation" : "Vòstra organizacion",
    "Your phone number" : "Vòstre numèro de telefòn",
    "Edit your Profile visibility" : "Modificatz la visibilitat de vòstre perfil",
    "Your role" : "Vòstre ròtle",
    "Add" : "Ajustar",
    "Create" : "Crear",
    "Change" : "Modificar",
    "Delete" : "Suprimir",
    "Reshare" : "Repartir",
    "Default language" : "Lenga per defaut",
    "Common languages" : "Lengas comunas",
    "Other languages" : "Autras lengas",
    "New user" : "Utilizaire novèl",
    "Display name" : "Nom afichat",
    "Email" : "Adreça corrièl",
    "Quota" : "Quota",
    "Language" : "Lenga",
    "Avatar" : "Avatar",
    "Username" : "Nom d'utilizaire",
    "Last login" : "Darrièra connexion",
    "Add user to group" : "Apondre utilizaire al grop",
    "{size} used" : "{size} utilizat",
    "Resend welcome email" : "Tornar enviar l’email de benvenguda",
    "Account deletion" : "Supression de compte",
    "Delete {userid}'s account" : "Suprimir lo compte de {userid}",
    "Welcome mail sent!" : "Email de benvenguda enviat !",
    "Done" : "Done",
    "Edit" : "Modificar",
    "Visibility" : "Visibilitat",
    "Show last login" : "Afichar la darrièra connexion",
    "Send email" : "Enviar email",
    "Default quota" : "Quota per defaut",
    "Adding your device …" : "Apondon del periferic…",
    "Unnamed device" : "Periferic sens nom",
    "Passwordless Authentication" : "Autentificacion sens senhal",
    "No devices configured." : "Cap de periferic pas configurat.",
    "Your browser does not support WebAuthn." : "Vòstre navigador es pas compatible amb WebAuthn.",
    "Admins" : "Admins",
    "Group name" : "Nom del grop",
    "Sending…" : "Mandadís…",
    "Email sent" : "Corrièl mandat",
    "Location" : "Emplaçament",
    "Profile picture" : "Imatge de perfil",
    "About" : "A prepaus",
    "Full name" : "Nom complèt",
    "Additional email" : "Email suplementari",
    "Headline" : "Títol",
    "Organisation" : "Organizacion",
    "Phone number" : "Numèro de telefòn",
    "Role" : "Ròtle",
    "Website" : "Site web",
    "Profile visibility" : "Visibilitat perfil",
    "Locale" : "Varianta lingüistica",
    "Your apps" : "Vòstras aplicacions",
    "Active apps" : "Aplicacions activas",
    "Disabled apps" : "Aplicacions desactivadas",
    "Updates" : "Mesas a jorn",
    "Show to everyone" : "Afichar a tot lo monde",
    "Hide" : "Amagar",
    "Never" : "Pas jamais",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
    "Forum" : "Forum",
    "Open documentation" : "Dobrir la documentacion",
    "Send mode" : "Mòde de mandadís",
    "Encryption" : "Chiframent",
    "Server address" : "Adreça del servidor",
    "Port" : "Pòrt",
    "Authentication" : "Autentificacion",
    "Authentication required" : "Autentificacion requerida",
    "Credentials" : "Informacions d'identificacion",
    "SMTP Password" : "Senhal SMTP",
    "Save" : "Salvar",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desvolopat per la {communityopen}comunautat Nextcloud{linkclose}, lo {githubopen}còdi font{linkclose} es jos licéncia {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Aimar nòstra pagina Facebook",
    "Follow us on Twitter" : "Nos seguir sus Twitter",
    "Follow us on Mastodon" : "Nos seguir sus Mastodon",
    "Check out our blog" : "Donar un còp d’uèlh a nòstre blòg",
    "Subscribe to our newsletter" : "S’abonar a l’infoletra",
    "Invalid user" : "Utilizaire invalid",
    "Your username is: %s" : "Vòstre nom d’utilizaire : %s",
    "Enable all" : "Activar tot",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Copied!" : "Copiat !",
    "Copy" : "Copiar",
    "Your email address" : "Vòstra adreça electronica",
    "Additional emails" : "Emails suplementaris",
    "Enable Profile" : "Activar Perfil",
    "Add new password" : "Apondre senhal novèl",
    "Add new email address" : "Apondre adreça electronica",
    "Set user as admin for" : "Definir l’utilizaire coma admin per",
    "Select user quota" : "Seleccionar lo quota utilizaire",
    "Delete user" : "Suprimir l’utilizaire",
    "Wipe all devices" : "Escafar totes los periferics",
    "Disable user" : "Desactivar l’utilizaire",
    "Enable user" : "Activar l’utilizaire",
    "Edit User" : "Modificar l’utilizaire",
    "Add a new user" : "Apondre un utilizaire novè",
    "No users in here" : "Cap d’utilizaire aquí",
    "Name your device" : "Nommatz vòstre periferic",
    "by {author}\n{license}" : "per {author}\n{license}",
    "Enter group name" : "Picatz un nom de grop",
    "Add group" : "Apondre grop",
    "Active users" : "Utilizaires actius",
    "Disabled users" : "Utilizaires desactivats",
    "Show Languages" : "Veire las lengas",
    "Not saved" : "Pas enregistrat",
    "Twitter" : "Twitter",
    "SMTP Username" : "Utilizaire SMTP",
    "day(s)" : "jorn(s)",
    "Set default expiration date" : "Definir una data d’expiracion per defaut"
},
"nplurals=2; plural=(n > 1);");
